#!/bin/bash

# Zenwalk Gnu/Linux build script written for "e17_modules"
# Soft Home Page: http://www.enlightenment.org
# Source URL: Enlightenment CVS
# Software's Dependencies: "alsa-lib,e17_libs,libxml2,libxslt,xorg,zlib"
# Package Maintainer: Michael Verret (AxXium) axxium.zenlnx@gmail.com
# Date of script Revision: Thursday 28 June 2007


#------------------( Unique Package Variables )


SOURCEVERSION="CVS20070628"
SOFT='e17_modules'
SOFTVERSION='0.16.999.039'		# Obtain the version from the e17_base's source code file configure.in
BUILDVERSION='48.3'
ARCH='i686'
CPU='i686'
DOCS="ABOUT-NLS AUTHORS BUGS COPYING COPYING-PLAIN INSTALL README TODO"
#      |-----handy-ruler------------------------------------------------------|
DESC_LINE_01="Numerous useful and fun modules for Enlightenment DR 17"
DESC_LINE_02=""
DESC_LINE_03="This package contains numerous useful and fun modules for"
DESC_LINE_04="Enlightenment DR 17. The included modules range from alarm"
DESC_LINE_05="to wlan and everything in between. These modules are extra"
DESC_LINE_06="and are not part of the default modules included in the"
DESC_LINE_07="e17_base package. They are also not developed by the core"
DESC_LINE_08="Enlightement developers. However, many you will find hard"
DESC_LINE_09="to live without and the others are just fun to use."
DESC_LINE_10=""
DESC_LINE_11=""


#------------------( Standard Variables & Routines )


REACTOR="$SOFT-$SOFTVERSION"
BUILDIR=$(pwd)
cd $BUILDIR
PACKAGE="$REACTOR-$ARCH-$BUILDVERSION"
DEST="$BUILDIR/$PACKAGE"

rm -rf {$DEST,$DEST.dep,$DEST.md5,$DEST.tgz,$PACKAGE,$PACKAGE.dep,$PACKAGE.md5} 1>/dev/null 2>&1

mkdir -p {$DEST,$DEST/usr/doc/$REACTOR,$DEST/install,$DEST/usr/src/$REACTOR}


#------------------( Configuration and Compilation )



SOURCES="\
alarm-$SOURCEVERSION.tar.bz2 \
bling-$SOURCEVERSION.tar.bz2 \
cpu-$SOURCEVERSION.tar.bz2 \
deskshow-$SOURCEVERSION.tar.bz2 \
emu-$SOURCEVERSION.tar.bz2 \
flame-$SOURCEVERSION.tar.bz2 \
forecasts-$SOURCEVERSION.tar.bz2 \
language-$SOURCEVERSION.tar.bz2 \
mail-$SOURCEVERSION.tar.bz2 \
mem-$SOURCEVERSION.tar.bz2 \
mixer-$SOURCEVERSION.tar.bz2 \
net-$SOURCEVERSION.tar.bz2 \
news-$SOURCEVERSION.tar.bz2 \
photo-$SOURCEVERSION.tar.bz2 \
rain-$SOURCEVERSION.tar.bz2 \
screenshot-$SOURCEVERSION.tar.bz2 \
slideshow-$SOURCEVERSION.tar.bz2 \
snow-$SOURCEVERSION.tar.bz2 \
taskbar-$SOURCEVERSION.tar.bz2 \
tclock-$SOURCEVERSION.tar.bz2 \
uptime-$SOURCEVERSION.tar.bz2 \
weather-$SOURCEVERSION.tar.bz2 \
winselector-$SOURCEVERSION.tar.bz2 \
wlan-$SOURCEVERSION.tar.bz2 "

for file in $SOURCES ; do
  echo -n "$file :"
  if [ -e $file ]; then
    echo " OK"
  else
    echo " missing !"
    exit 1
  fi
done

for file in $SOURCES ; do
  if [ "$(echo $file | grep ".tar.bz2" )" ]; then
      SOURCEDIR="$(basename $file .tar.bz2)"
      rm -rf $SOURCEDIR
      tar jxvf $file
  elif [ "$(echo $file | grep ".tar.gz" )" ]; then
      SOURCEDIR="$(basename $file .tar.gz)"
      rm -rf $SOURCEDIR
      tar zxvf $file
  fi

mkdir -p {$DEST,$DEST/usr/doc/$REACTOR,$DEST/install,$DEST/usr/src/$REACTOR}

  (
    cd $SOURCEDIR
    chown -R root.root .
    find . -perm 777 -exec chmod 755 {} \;
    find . -perm 775 -exec chmod 755 {} \;
    find . -perm 666 -exec chmod 644 {} \;
    find . -perm 664 -exec chmod 644 {} \;

    export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
    export CXXFLAGS="$CFLAGS"

    ./autogen.sh --prefix=/usr

    ./configure --prefix=/usr \
    --bindir=/usr/bin \
    --sbindir=/sbin \
    --libexecdir=/usr/libexec \
    --sysconfdir=/etc \
    --sharedstatedir=/usr/com \
    --localstatedir=/var \
    --libdir=/usr/lib \
    --includedir=/usr/include \
    --oldincludedir=/usr/include \
    --datarootdir=/usr/share \
    --infodir=/usr/info \
    --localedir=/usr/share/locale \
    --mandir=/usr/man \
    --docdir=/usr/doc/$REACTOR/$DOCDIR \
    --htmldir=/usr/doc/$REACTOR/$DOCDIR/html \
    --dvidir=/usr/doc/$REACTOR/$DOCDIR/dvi \
    --pdfdir=/usr/doc/$REACTOR/$DOCDIR/pdf \
    --psdir=/usr/doc/$REACTOR/$DOCDIR/ps

    make -j4
    make install DESTDIR=$DEST

    mkdir -p $DEST/usr/doc/$REACTOR/$SOURCEDIR
    cp -a \
      AUTHORS COPYING INSTALL NEWS README TODO ChangeLog \
      $DEST/usr/doc/$REACTOR/$SOURCEDIR  1>/dev/null 2>&1
  )

  rm -rf $SOURCEDIR
done


#------------------( Stripping )


( cd $DEST
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)


#------------------( Strip Date From Documentation Directories )


( cd $DEST/usr/doc/$REACTOR
for f in *-$SOURCEVERSION; do mv "$f" $DEST/usr/doc/$REACTOR/"${f%-$SOURCEVERSION}"; done
)


#------------------( Delete Empty Documentation Files )


( cd $DEST/usr/doc/
  find ./*/ -empty -delete
)


#------------------( Begin Packaging )


cat <<EOF > $DEST/install/slack-desc 
      |-----handy-ruler------------------------------------------------------|
$SOFT: $DESC_LINE_01
$SOFT: $DESC_LINE_02
$SOFT: $DESC_LINE_03
$SOFT: $DESC_LINE_04
$SOFT: $DESC_LINE_05
$SOFT: $DESC_LINE_06
$SOFT: $DESC_LINE_07
$SOFT: $DESC_LINE_08
$SOFT: $DESC_LINE_09
$SOFT: $DESC_LINE_10
$SOFT: $DESC_LINE_11
EOF

cp $BUILDIR/build-$SOFT.sh $DEST/usr/src/$REACTOR/build-$SOFT.sh

cd $DEST
requiredbuilder -z $DEST >> $BUILDIR/$PACKAGE.dep

makepkg -l y -c n ../$PACKAGE.tgz
cd $BUILDIR
rm -rf {$DEST,$REACTOR}

md5sum $PACKAGE.tgz > $PACKAGE.md5